@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -85,7 +85,7 @@ class IgnoreUserAbort extends AbstractPlugin
     public function onBefore(Event $event)
     {
         if ($this->activatedTarget === null && !ignore_user_abort(true)) {
-            $this->activatedTarget = $event->getTarget();
+            $this->activatedTarget = $event->getStorage();
         }
     }
 
@@ -101,7 +101,7 @@ class IgnoreUserAbort extends AbstractPlugin
      */
     public function onAfter(Event $event)
     {
-        if ($this->activatedTarget === $event->getTarget()) {
+        if ($this->activatedTarget === $event->getStorage()) {
             // exit if connection aborted
             if ($this->getOptions()->getExitOnAbort() && connection_aborted()) {
                 exit;
