@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -125,7 +125,6 @@ class Reader
         static::$httpClient = $httpClient;
     }
 
-
     /**
      * Gets the HTTP client object. If none is set, a new ZendHttp\Client will be used.
      *
@@ -192,7 +191,6 @@ class Reader
     {
         $cache       = self::getCache();
         $feed        = null;
-        $responseXml = '';
         $client      = self::getHttpClient();
         $client->resetParameters();
         $headers = new ZendHttp\Headers();
@@ -266,7 +264,7 @@ class Reader
      * HTTP client implementations.
      *
      * @param  string $uri
-     * @param  Http\Client $client
+     * @param  Http\ClientInterface $client
      * @return self
      * @throws Exception\RuntimeException if response is not an Http\ResponseInterface
      */
