@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -586,9 +586,9 @@ class Fieldset extends Element implements FieldsetInterface
             }
 
             // skip post values for disabled elements, get old value from object
-            if(!$element->hasAttribute('disabled')) {
+            if (!$element->getAttribute('disabled')) {
                 $hydratableData[$name] = $value;
-            } elseif(array_key_exists($name, $objectData)) {
+            } elseif (array_key_exists($name, $objectData)) {
                 $hydratableData[$name] = $objectData[$name];
             }
         }
