@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -68,11 +68,10 @@ class RouteListener implements ListenerAggregateInterface
 
             $results = $target->getEventManager()->trigger(MvcEvent::EVENT_DISPATCH_ERROR, $e);
             if (count($results)) {
-                $return  = $results->last();
-            } else {
-                $return = $e->getParams();
+                return $results->last();
             }
-            return $return;
+
+            return $e->getParams();
         }
 
         $e->setRouteMatch($routeMatch);
