@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -126,8 +126,11 @@ class FlashMessenger extends AbstractTranslatorHelper implements ServiceLocatorA
      * @param  array $classes
      * @return string
      */
-    protected function renderMessages($namespace = PluginFlashMessenger::NAMESPACE_DEFAULT, array $messages = array(), array $classes = array())
-    {
+    protected function renderMessages(
+        $namespace = PluginFlashMessenger::NAMESPACE_DEFAULT,
+        array $messages = array(),
+        array $classes = array()
+    ) {
         // Prepare classes for opening tag
         if (empty($classes)) {
             if (isset($this->classMessages[$namespace])) {
@@ -142,21 +145,27 @@ class FlashMessenger extends AbstractTranslatorHelper implements ServiceLocatorA
         $messagesToPrint = array();
         $translator = $this->getTranslator();
         $translatorTextDomain = $this->getTranslatorTextDomain();
-        array_walk_recursive($messages, function ($item) use (&$messagesToPrint, $escapeHtml, $translator, $translatorTextDomain) {
-            if ($translator !== null) {
-                $item = $translator->translate(
-                    $item,
-                    $translatorTextDomain
-                );
+        array_walk_recursive(
+            $messages,
+            function ($item) use (&$messagesToPrint, $escapeHtml, $translator, $translatorTextDomain) {
+                if ($translator !== null) {
+                    $item = $translator->translate(
+                        $item,
+                        $translatorTextDomain
+                    );
+                }
+                $messagesToPrint[] = $escapeHtml($item);
             }
-            $messagesToPrint[] = $escapeHtml($item);
-        });
+        );
         if (empty($messagesToPrint)) {
             return '';
         }
         // Generate markup
         $markup  = sprintf($this->getMessageOpenFormat(), ' class="' . implode(' ', $classes) . '"');
-        $markup .= implode(sprintf($this->getMessageSeparatorString(), ' class="' . implode(' ', $classes) . '"'), $messagesToPrint);
+        $markup .= implode(
+            sprintf($this->getMessageSeparatorString(), ' class="' . implode(' ', $classes) . '"'),
+            $messagesToPrint
+        );
         $markup .= $this->getMessageCloseString();
         return $markup;
     }
